@@ -2,11 +2,17 @@ package FBP::Control;
 
 use Mouse::Role;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 has default => (
 	is  => 'ro',
 	isa => 'Bool',
 );
 
+has permission => (
+	is       => 'ro',
+	isa      => 'Str',
+	required => 1,
+);
+
 1;
